The fixed-width integer domains (numbers/i8 .. numbers/i128,
numbers/u8 .. numbers/u128): their literals, values, and the widening
promotion edges through the signed and unsigned integer lattice.
Structs
- Fixed
Numbers Lib - The library that installs every fixed-width integer domain (
numbers/i8throughnumbers/i128,numbers/u8throughnumbers/u128, and the pointer-widthisize/usize): their literal classes and shapes, value shapes, and the widening promotion edges through the integer lattice.